@@ -24,19 +24,16 @@
 #'
 #' @seealso \code{\link{summary.sampling}} to summarize results
 #' @export
-randomizer <- function(
-  dataset, vars,
-  conditions = c("A", "B"),
-  blocks = NULL, probs = NULL,
-  label = ".conditions",
-  seed = 1234, data_filter = "",
-  na.rm = FALSE,
-  envir = parent.frame()
-) {
-
+randomizer <- function(dataset, vars,
+                       conditions = c("A", "B"),
+                       blocks = NULL, probs = NULL,
+                       label = ".conditions",
+                       seed = 1234, data_filter = "",
+                       na.rm = FALSE,
+                       envir = parent.frame()) {
   df_name <- if (is_string(dataset)) dataset else deparse(substitute(dataset))
 
-  if (!radiant.data::is_empty(blocks)) {
+  if (!is.empty(blocks)) {
     vars <- c(vars, blocks)
   }
 
@@ -44,10 +41,11 @@ randomizer <- function(
 
   ## use seed if provided
   seed <- gsub("[^0-9]", "", seed)
-  if (!radiant.data::is_empty(seed)) set.seed(seed)
+  if (!is.empty(seed)) set.seed(seed)
 
-  if (radiant.data::is_empty(probs)) {
-    probs <- length(conditions) %>% {rep(1/., .)}
+  if (is.empty(probs)) {
+    probs <- length(conditions) %>%
+      (function(x) rep(1 / x, x))
   } else if (length(probs) == 1) {
     probs <- rep(probs, length(conditions))
   } else if (length(probs) != length(conditions)) {
@@ -91,16 +89,16 @@ randomizer <- function(
 #'
 #' @export
 summary.randomizer <- function(object, dec = 3, ...) {
-  if (radiant.data::is_empty(object$blocks)) {
+  if (is.empty(object$blocks)) {
     cat("Random assignment (simple random)\n")
   } else {
     cat("Random assignment (blocking)\n")
   }
   cat("Data         :", object$df_name, "\n")
-  if (!radiant.data::is_empty(object$data_filter)) {
+  if (!is.empty(object$data_filter)) {
     cat("Filter       :", gsub("\\n", "", object$data_filter), "\n")
   }
-  if (!radiant.data::is_empty(object$blocks)) {
+  if (!is.empty(object$blocks)) {
     cat("Variables    :", setdiff(object$vars, object$blocks), "\n")
     cat("Blocks       :", object$blocks, "\n")
   } else {
@@ -108,21 +106,26 @@ summary.randomizer <- function(object, dec = 3, ...) {
   }
   cat("Conditions   :", object$conditions, "\n")
   cat("Probabilities:", round(object$probs, dec), "\n")
-  if (!radiant.data::is_empty(object$seed)) {
+  if (!is.empty(object$seed)) {
     cat("Random seed  :", object$seed, "\n")
   }
   is_unique <- object$dataset[, -1, drop = FALSE] %>%
-    {ifelse(nrow(.) > nrow(distinct(.)), "Based on selected variables some duplicate rows exist", "Based on selected variables, no duplicate rows exist")}
+    (function(x) ifelse(nrow(x) > nrow(distinct(x)), "Based on selected variables some duplicate rows exist", "Based on selected variables, no duplicate rows exist"))
   cat("Duplicates   :", is_unique, "\n\n")
 
   cat("Assigment frequencies:\n")
-  if (radiant.data::is_empty(object$blocks_vct)) {
+  if (is.empty(object$blocks_vct)) {
     tab <- table(object$dataset[[object$label]])
   } else {
     tab <- table(object$blocks_vct, object$dataset[[object$label]])
   }
-  tab %>% addmargins() %>% print()
+  tab %>%
+    addmargins() %>%
+    print()
 
   cat("\nAssigment proportions:\n")
-  tab %>% prop.table() %>% round(dec) %>% print()
+  tab %>%
+    prop.table() %>%
+    round(dec) %>%
+    print()
 }
