@@ -17,19 +17,19 @@
 #'
 #' @seealso \code{\link{summary.sampling}} to summarize results
 #' @export
-sampling <- function(
-  dataset, vars, sample_size,
-  seed = 1234, data_filter = "",
-  na.rm = FALSE,  envir = parent.frame()
-) {
-
+sampling <- function(dataset, vars, sample_size,
+                     seed = 1234, data_filter = "",
+                     na.rm = FALSE, envir = parent.frame()) {
   df_name <- if (is_string(dataset)) dataset else deparse(substitute(dataset))
   dataset <- get_data(dataset, vars, filt = data_filter, na.rm = na.rm, envir = envir)
-  if (is_not(sample_size)) return(add_class("Please select a sample size of 1 or greater", "sampling"))
+  if (is_not(sample_size)) {
+    return(add_class("Please select a sample size of 1 or greater", "sampling"))
+  }
 
   ## use seed if provided
-  seed %>% gsub("[^0-9]", "", .) %>%
-    {if (!radiant.data::is_empty(.)) set.seed(.)}
+  seed %>%
+    gsub("[^0-9]", "", .) %>%
+    (function(x) if (!is.empty(x)) set.seed(x))
 
   rnd_number <- data.frame(rnd_number = runif(nrow(dataset), min = 0, max = 1))
   dataset <- bind_cols(rnd_number, dataset)
@@ -61,20 +61,20 @@ sampling <- function(
 summary.sampling <- function(object, dec = 3, ...) {
   cat("Sampling (simple random)\n")
   cat("Data       :", object$df_name, "\n")
-  if (!radiant.data::is_empty(object$data_filter)) {
+  if (!is.empty(object$data_filter)) {
     cat("Filter     :", gsub("\\n", "", object$data_filter), "\n")
   }
   cat("Variables  :", object$var, "\n")
-  if (!radiant.data::is_empty(object$seed)) {
+  if (!is.empty(object$seed)) {
     cat("Random seed:", object$seed, "\n")
   }
-  if (radiant.data::is_empty(object$sample_size) || object$sample_size < 1) {
+  if (is.empty(object$sample_size) || object$sample_size < 1) {
     cat("Sample size: 1 (invalid input provided)\n")
   } else {
     cat("Sample size:", object$sample_size, "\n")
   }
 
   is_unique <- object$dataset[, -1, drop = FALSE] %>%
-    {ifelse(nrow(.) > nrow(distinct(.)), "Based on selected variables some duplicate rows exist", "Based on selected variables, no duplicate rows exist")}
+    (function(x) ifelse(nrow(x) > nrow(distinct(x)), "Based on selected variables some duplicate rows exist", "Based on selected variables, no duplicate rows exist"))
   cat("Duplicates :", is_unique, "\n\n")
 }
